/*
This sketch reads analog sensors on pins A0, A1 & A2 and sends their values to the serial port for use in Max, Processing, etc.
It averages the current and previous readings for each given sensor in order to do a small amount of smoothing.
It does not preserve the 10-bit resolution of the analog pins; it scales the readings to 8-bit range.
It uses arrays to hold: 1) the sensor pin numbers; 2) the previous values of the sensor readings for averaging.
It implements a simple hand-shaking protocol which waits to read & send sensors until receiving a byte from the software (Max, Processing, etc.)

Steven M. Miller
*/

int SensorPins[3] = {0, 1, 2};      // Array to hold pin numbers of sensors
                                    // fill with first 3 analog pins as default
                                    // **NOTE: Change these numbers if using other pins
                                    
int SensorPrevVals[3] = {0, 0, 0};  // Array to hold previous sensor values
                                    // fill with default value of 0

int Val = 0;                        // Variable for current value read from sensor pin
int NewVal = 0;                     // Averaged sensor value ((current + previous) / 2)
int i = 0;                          // Index for for-loop
int inByte = 0;                     // Variable to hold incoming serial data

void setup()
{
  Serial.begin(9600); 
}

void loop()
{
  if(Serial.available()>0)                      // Is there data waiting in the serial port?
  {                                             // If so, proceed with the following code block, otherwise jump to end of loop
  inByte = Serial.read();                       // Read data from serial buffer and store in variable (to get rid of it)
  
    for(i = 0; i < 3; i = i + 1){
      Val = analogRead(SensorPins[i]);          // Read sensor value and store in Val
      NewVal = (Val + SensorPrevVals[i]) / 2;   // Average current and previous values
      SensorPrevVals[i] = Val;                  // Store current Val as PrevVal for next time
      Serial.write(NewVal/4);                   // Scale NewVal from int to byte and send out
    }
    Serial.println();                           // Send CR & LF (ASCII 13 & 10) to mark end of message
  }
}

